/*
 * Copyright (C) 2010-2011, Pedro Ballesteros <pedro@theprogrammingchronicles.com>
 *
 * This file is part of The Programming Chronicles Test-Driven Development
 * Exercises(http://theprogrammingchronicles.com/)
 *
 * This copyrighted material is free software: you can redistribute it
 * and/or modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This material is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this material. This copy is available in LICENSE-GPL.txt
 * file. If not, see <http://www.gnu.org/licenses/>.
 */

package com.programmingchronicles.tdd.addressbook;

import com.programmingchronicles.tdd.domain.Contact;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Servicio de Agenda de Contactos basado en memoria.
 *
 * <p>Se comienza la implementación de un servicio Agenda de Contactos Global
 * basado en el almacenamiento en memoria.</p>
 *
 * <p>Se implementan dos comportamientos, el de añadir un contacto a la
 * agenda y el de obtener un contacto de la agenda.</p>
 *
 * <p>Durante la implementación del comportamiento de obtener agenda
 * vemos necesario que el comportamiento de añadir devuelva identificadores</p>
 *
 * <p>Implementar el servicio con almacenamiento en memoria no tiene que ver
 * con el uso de TDD, se podría empezar directamente con una implementación basada
 * en base de datos. Se implementa de esta forma para simplificar los ejercicios
 * iniciales</p>
 *
 * @author Pedro Ballesteros <pedro@theprogrammingchronicles.com>
 */
public class GlobalAddressBook {

    private static int nextId = 0;
    private Map<String, Contact> addressBookMap = new HashMap();

    /**
     * Añade el contacto entregado a la agenda global devolviendo
     * un id único para el contacto.
     *
     * @param contact Datos del contacto a añadir
     * @return Devuelve el id asignado al contacto
     */
    public String addContact(Contact contact) {
        // Se tiene que generar un id único para el contacto
        String id = Integer.toString(nextId);
        nextId++;

        contact.setId(id);
        addressBookMap.put(id, contact);
        return id;
    }

    /**
     * Obtiene todos los contactos del sistema.
     *
     * @return
     */
    public List<Contact> getAll() {
        List<Contact> contacts = new ArrayList(addressBookMap.size());
        contacts.addAll(addressBookMap.values());
        return contacts;
    }

    /**
     * Obtiene el contacto asociado al id entregado.
     *
     * @param contactId id del contacto
     * @return Devuelve el contacto
     */
    public Contact getContact(String contactId) {
        return addressBookMap.get(contactId);
    }
}
